# coding: utf-8

NAME = "fastpip"
version = 0, 11, 2
AUTHOR = "hrpzcf"
EMAIL = "hrpzcf@foxmail.com"
WEBSITE = "https://gitee.com/hrpzcf/fastpip"
VERSION = ".".join(map(str, version))

__all__ = ["NAME", "AUTHOR", "EMAIL", "WEBSITE", "VERSION", "version"]
